(full-name-i18n category-id)Returns an i18n entity representing the full name of a category
Returns an i18n entity representing the full name of a category
(options culture & [ids])Returns a map of ids to the full names of the corresponding categories. Given an example category 17592186046253, returns: {17592186046253 'Women / Shirts'}
Returns a map of ids to the full names of the corresponding categories.
Given an example category 17592186046253, returns:
{17592186046253 'Women / Shirts'}(options-without-branches culture)Like options but excludes branches (categories that have children)
Like options but excludes branches (categories that have children)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |